@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-import sys
 import inspect
-from typing import Callable, TYPE_CHECKING
+import sys
+from typing import Callable
 
 import rich.repr
 from rich.console import RenderableType
@@ -13,9 +13,6 @@ __all__ = ["log", "panic"]
 from ._context import active_app
 from ._log import LogGroup, LogVerbosity
 
-if TYPE_CHECKING:
-    from .app import App
-
 if sys.version_info >= (3, 10):
     from typing import TypeAlias
 else:  # pragma: no cover
@@ -51,7 +48,9 @@ class Logger:
         try:
             app = active_app.get()
         except LookupError:
-            raise LoggerError("Unable to log without an active app.") from None
+            print_args = (*args, *[f"{key}={value!r}" for key, value in kwargs.items()])
+            print(*print_args)
+            return
         if app.devtools is None or not app.devtools.is_connected:
             return
 
