@@ -7,14 +7,12 @@ import os.path
 
 from rich.console import RenderableType
 import rich.repr
-from rich.text import Text
-from rich.tree import Tree
 
-from .. import events
+from rich.text import Text
+
 from ..message import Message
-from ..reactive import Reactive
 from .._types import MessageTarget
-from . import TreeControl, TreeClick, TreeNode, NodeID
+from ._tree_control import TreeControl, TreeNode
 
 
 @dataclass
@@ -23,36 +21,27 @@ class DirEntry:
     is_dir: bool
 
 
-@rich.repr.auto
-class FileClick(Message, bubble=True):
-    def __init__(self, sender: MessageTarget, path: str) -> None:
-        self.path = path
-        super().__init__(sender)
-
-
 class DirectoryTree(TreeControl[DirEntry]):
-    def __init__(self, path: str, name: str = None) -> None:
-        self.path = path.rstrip("/")
+    @rich.repr.auto
+    class FileClick(Message, bubble=True):
+        def __init__(self, sender: MessageTarget, path: str) -> None:
+            self.path = path
+            super().__init__(sender)
+
+    def __init__(
+        self,
+        path: str,
+        *,
+        name: str | None = None,
+        id: str | None = None,
+        classes: str | None = None,
+    ) -> None:
+        self.path = os.path.expanduser(path.rstrip("/"))
         label = os.path.basename(self.path)
-        data = DirEntry(path, True)
-        super().__init__(label, name=name, data=data)
+        data = DirEntry(self.path, True)
+        super().__init__(label, data, name=name, id=id, classes=classes)
         self.root.tree.guide_style = "black"
 
-    has_focus: Reactive[bool] = Reactive(False)
-
-    def on_focus(self) -> None:
-        self.has_focus = True
-
-    def on_blur(self) -> None:
-        self.has_focus = False
-
-    async def watch_hover_node(self, hover_node: NodeID) -> None:
-        for node in self.nodes.values():
-            node.tree.guide_style = (
-                "bold not dim red" if node.id == hover_node else "black"
-            )
-        self.refresh(layout=True)
-
     def render_node(self, node: TreeNode[DirEntry]) -> RenderableType:
         return self.render_tree_label(
             node,
@@ -82,25 +71,28 @@ class DirectoryTree(TreeControl[DirEntry]):
         if is_hover:
             label.stylize("underline")
         if is_dir:
-            label.stylize("bold magenta")
+            label.stylize("bold")
             icon = "📂" if expanded else "📁"
         else:
-            label.stylize("bright_green")
             icon = "📄"
-            label.highlight_regex(r"\..*$", "green")
+            label.highlight_regex(r"\..*$", "italic")
 
         if label.plain.startswith("."):
             label.stylize("dim")
 
         if is_cursor and has_focus:
-            label.stylize("reverse")
+            cursor_style = self.get_component_styles("tree--cursor").rich_style
+            label.stylize(cursor_style)
 
         icon_label = Text(f"{icon} ", no_wrap=True, overflow="ellipsis") + label
         icon_label.apply_meta(meta)
         return icon_label
 
-    async def on_mount(self, event: events.Mount) -> None:
-        await self.load_directory(self.root)
+    def on_styles_updated(self) -> None:
+        self.render_tree_label.cache_clear()
+
+    def on_mount(self) -> None:
+        self.call_later(self.load_directory, self.root)
 
     async def load_directory(self, node: TreeNode[DirEntry]):
         path = node.data.path
@@ -108,29 +100,20 @@ class DirectoryTree(TreeControl[DirEntry]):
             list(scandir(path)), key=lambda entry: (not entry.is_dir(), entry.name)
         )
         for entry in directory:
-            await node.add(entry.name, DirEntry(entry.path, entry.is_dir()))
+            node.add(entry.name, DirEntry(entry.path, entry.is_dir()))
         node.loaded = True
-        await node.expand()
+        node.expand()
         self.refresh(layout=True)
 
-    async def handle_tree_click(self, message: TreeClick[DirEntry]) -> None:
+    async def on_tree_control_node_selected(
+        self, message: TreeControl.NodeSelected[DirEntry]
+    ) -> None:
         dir_entry = message.node.data
         if not dir_entry.is_dir:
-            await self.emit(FileClick(self, dir_entry.path))
+            await self.emit(self.FileClick(self, dir_entry.path))
         else:
             if not message.node.loaded:
                 await self.load_directory(message.node)
-                await message.node.expand()
+                message.node.expand()
             else:
-                await message.node.toggle()
-
-
-if __name__ == "__main__":
-    from textual import events
-    from textual.app import App
-
-    class TreeApp(App):
-        async def on_mount(self, event: events.Mount) -> None:
-            await self.view.dock(DirectoryTree("/Users/willmcgugan/projects"))
-
-    TreeApp.run(log="textual.log")
+                message.node.toggle()
